@@ -8,6 +8,7 @@ from sqlalchemy import (
     Text,
     String,
     DECIMAL,
+    Boolean,
 )
 
 from ...database import Base
@@ -37,6 +38,7 @@ class DealOutboxModel(Base):
         nullable=True,
     )
     investors = Column(Text, nullable=True)
+    reviewed = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
