@@ -5,6 +5,7 @@ from sqlalchemy import (
     Integer,
     String,
     DateTime,
+    Boolean,
 )
 
 from ...database import Base
@@ -17,6 +18,7 @@ class MeetingModel(Base):
     meeting_name = Column(String(191), nullable=False, index=True)
     start_date = Column(DateTime, nullable=False)
     end_date = Column(DateTime, nullable=False)
+    from_website = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
