@@ -6,6 +6,7 @@ from sqlalchemy import (
     DateTime,
     ForeignKey,
     Boolean,
+    String,
     Text,
 )
 
@@ -21,12 +22,14 @@ class NewswireTableModel(Base):
         ForeignKey('newswires.id'),
         nullable=False,
     )
+    table_text = Column(Text, nullable=False)
     table_info = Column(Text, nullable=True)
     table_html_file_id = Column(
         Integer,
         ForeignKey('files.id'),
         nullable=True,
     )
+    table_hash = Column(String(64), nullable=True)
     is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
