@@ -10,7 +10,9 @@ class NewswireTableResourceSchema(Schema):
 
     id = fields.Integer(dump_only=True)
     news_id = fields.Integer(required=True)
+    table_text = fields.String(required=True)
     table_info = fields.String(allow_none=True)
     table_html_file_id = fields.Integer(allow_none=True)
+    table_hash = fields.String(allow_none=True)
     is_deleted = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
