@@ -16,16 +16,20 @@ class PatentApplicationModel(Base):
 
     id = Column(Integer, primary_key=True)
     application_number = Column(String(128), nullable=False)
+    document_number = Column(String(128), nullable=True)
     jurisdiction = Column(String(128), nullable=False)
     app_grp_art_number = Column(Integer, nullable=True)
-    abstract_text = Column(Text)
-    description = Column(Text)
-    filed_date = Column(DateTime)
-    inventors = Column(Text)
-    applicant = Column(Text)
-    app_class = Column(String(20))
-    app_sub_class = Column(String(20))
+    abstract_text = Column(Text, nullable=True)
+    description = Column(Text, nullable=True)
+    filed_date = Column(DateTime, nullable=True)
+    published_date = Column(DateTime, nullable=True)
+    inventors = Column(Text, nullable=True)
+    applicant = Column(Text, nullable=True)
+    app_class = Column(String(20), nullable=True)
+    app_sub_class = Column(String(20), nullable=True)
     title = Column(String(500))
+    docdb_family_id = Column(Integer, nullable=True)
+    inpadoc_family_id = Column(Integer, nullable=True)
 
     updated_at = Column(
         DateTime,
